@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2013 DNAnexus, Inc.
+# Copyright (C) 2013-2014 DNAnexus, Inc.
 #
 # This file is part of dx-toolkit (DNAnexus platform client libraries).
 #
@@ -19,10 +19,12 @@
 
 from __future__ import print_function
 
-import os, unittest, json, tempfile, subprocess, csv, shutil, re, time
-from dxpy import AppError
-from dxpy.utils import (describe, exec_utils, genomic_utils, response_iterator, get_futures_threadpool)
-from dxpy.compat import is_py2
+import unittest, time, json
+from dxpy import AppError, DXFile, DXRecord
+from dxpy.utils import (describe, exec_utils, genomic_utils, response_iterator, get_futures_threadpool, DXJSONEncoder)
+from dxpy.compat import USING_PYTHON2
+
+# TODO: unit tests for dxpy.utils.get_field_from_jbor, get_job_from_jbor, is_job_ref
 
 class TestDescribe(unittest.TestCase):
     def test_is_job_ref(self):
@@ -61,11 +63,11 @@ class TestErrorSanitizing(unittest.TestCase):
         self.assertEqual(exec_utils._safe_unicode(ValueError("foo")), "foo")
         # UTF-8 encoded str
         self.assertEqual(exec_utils._safe_unicode(ValueError(u"crème".encode("utf-8"))),
-                         u"cr\xe8me" if is_py2 else u"b'cr\\xc3\\xa8me'")
+                         u"cr\xe8me" if USING_PYTHON2 else u"b'cr\\xc3\\xa8me'")
         # Unicode obj
         self.assertEqual(exec_utils._safe_unicode(ValueError(u"brûlée")), u"br\xfbl\xe9e")
         # Not UTF-8
-        if is_py2:
+        if USING_PYTHON2:
             expected = "Invalid read name: D??n?x?s [Raw error message: 496e76616c69642072656164206e616d653a2044d1c16ee878fb73]"
         else:
             expected = "b'Invalid read name: D\\xd1\\xc1n\\xe8x\\xfbs'"
@@ -113,6 +115,14 @@ class TestResponseIterator(unittest.TestCase):
         for i, res in enumerate(response_iterator(tasks2(), get_futures_threadpool(5), num_retries=2, retry_after=0.1)):
             self.assertEqual(i, res)
 
+class TestDXUtils(unittest.TestCase):
+    def test_dxjsonencoder(self):
+        f = DXFile("file-" + "x"*24, project="project-" + "y"*24)
+        r = DXRecord("record-" + "r"*24, project="project-" + "y"*24)
+        data = {"a": [{"b": f}, r]}
+        serialized = json.dumps(data, cls=DXJSONEncoder)
+        self.assertEqual(serialized,
+                         '{"a": [{"b": {"$dnanexus_link": "file-xxxxxxxxxxxxxxxxxxxxxxxx"}}, {"$dnanexus_link": "record-rrrrrrrrrrrrrrrrrrrrrrrr"}]}')
 
 if __name__ == '__main__':
     unittest.main()
